datadir = "~/Documents/Dropbox/Research/trevor/public materials"

# load consonant harmony file
setwd(datadir)
lex = read.csv("trevor_harmony.csv")
lex$prod_new = factor(lex$prod_new, levels=names(rev(sort(xtabs(~ lex$prod_new)))))
levels(lex$prod_new)[5:8] = "other"
lex = subset(lex, prod_new!="other")
lex$prod_new = lex$prod_new[drop=T]

# load complex onset file
newcc = read.csv("trevor_complex_onsets.csv")
newcc$mapping = factor(newcc$mapping, levels=names(rev(sort(xtabs(~ mapping, data=newcc)))))

###################
### DONE LOADING DATA
###################

#########
# prepare for making charts
chartmode = "pdf"
chartmode = "screen"
myfont = "Linux Libertine"; pointsize=12
quartz.fnc = function(cwidth,cheight,cname) {
	if(chartmode=="screen") {
		quartz(width=cwidth,height=cheight)
	}
	if(chartmode=="pdf") {
		quartz(width=cwidth,height=cheight,type="pdf",file=cname)
	}
}
trevor.axes = function() {
	s = seq(365.25,365.25*3,60.875);
	axis(1,at=s,paste(floor(s/30.4375/12),(s/30.4375)%%12,sep=";"),cex.axis=1.5);
	axis(2,at=seq(0,1,.25),paste(seq(0,1,.25)*100,"%",sep=""),cex.axis=1.5);
}






##################
#     ONSETS
##################

quartz.fnc(cwidth=8,cheight=8,cname="n.onsets.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,5,1),mfrow=c(3,2))
for(clust in c("PR","TR","KR","sC")) {
	x = xtabs(~ faithful + Age_in_days, data=subset(newcc, cluster.type == clust));
	
	plot(x[2,]/colSums(x) ~ as.numeric(colnames(x)),cex=log(colSums(x)),xlim=c(360,1130),type="p", xlab="", ylab="faithful tokens", main= clust, col="gray50", lwd=.3, xaxt="n", yaxt="n", cex.axis=1.6, cex.lab=1.6, cex.main=2); trevor.axes()

	lex2=data.frame(age=as.numeric(colnames(x)),faith=as.numeric(x[2,]),unfaith=as.numeric(x[1,]), row.names=NULL);
	lex2.glm = glm(cbind(faith, unfaith) ~ age, family = "binomial", data = lex2);
	lex2$fittedbase = fitted(lex2.glm)
	lines(lex2$fittedbase ~ age, data=lex2, lwd=3)
}
if (chartmode=="pdf") {dev.off()}


quartz.fnc(cwidth=8,cheight=8,cname="n.onsets.dataonly2.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,5,1),mfrow=c(3,2))
for(clust in c("PR","TR","KR","sC")) {
	x = xtabs(~ faithful + Age_in_days, data=subset(newcc, cluster.type == clust));
	
	plot(x[2,]/colSums(x) ~ as.numeric(colnames(x)),cex=log(colSums(x)),xlim=c(360,1130),type="p", xlab="", ylab="", main="", col="gray50", lwd=.3, xaxt="n", yaxt="n", cex.axis=1.6, cex.lab=1.6, cex.main=2);# trevor.axes()

	lex2=data.frame(age=as.numeric(colnames(x)),faith=as.numeric(x[2,]),unfaith=as.numeric(x[1,]), row.names=NULL);
	lex2.glm = glm(cbind(faith, unfaith) ~ age, family = "binomial", data = lex2);
	lex2$fittedbase = fitted(lex2.glm)
	lines(lex2$fittedbase ~ age, data=lex2, lwd=3)

	d = as.data.frame(cbind(as.numeric(colnames(x)),x[2,]/colSums(x),log(colSums(x)), lex2$fittedbase));colnames(d)=c("age","bubble.height","bubble.size","line")
	write.table(d, row.names=F, sep="\t", paste("onset.data",clust,"txt",sep="."))
}
if (chartmode=="pdf") {dev.off()}







###########
#  Consonant harmony: all places
###########
quartz.fnc(cwidth=8,cheight=8,cname="n.harmony.by.places.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,5,1),mfrow=c(3,2))
for(place in c("TVK","KVT","PVK","KVP","PVT","TVP")) {
	x = xtabs(~ I(prod_new!="faithful") + I(days_old), data=subset(lex, places==place & days_old>360 & !deletion))
	lex2=data.frame(age=as.numeric(colnames(x)),faith=as.numeric(x[1,]), unfaith =as.numeric(x[2,]), row.names=NULL)
	lex2$total = lex2$faith + lex2$unfaith 

	lex2$age2 = lex2$age - 802
	lex2$indicator = lex2$age > 802

	lex2.glm  = glm(cbind(faith, unfaith) ~ age2          , family = "binomial", data = lex2);summary(lex2.glm)
	lex2.glm3 = glm(cbind(faith, unfaith) ~ age2:indicator, family = "binomial", data = lex2);summary(lex2.glm3)
	lex2$fitted = fitted(lex2.glm)
	lex2$fitted3 = fitted(lex2.glm3)
	anv = anova(lex2.glm,lex2.glm3,test="Chisq") 
	lex2 = subset(lex2,age<1130)
	plot(fitted ~ age, data=lex2,  type="n", xlab="", ylab="faithful tokens", cex.lab=1.6, ylim=c(0,1), xlim=c(360,1130), main=paste(place), yaxt="n", xaxt="n", cex.main=2);
	trevor.axes();		
	lines(faith/(faith+unfaith) ~ age, data=subset(lex2,age<1730), type="p", cex=log(lex2$faith+lex2$unfaith+.2), col="gray50", lwd=.3);

	if (place %in% c("KVT")) {
		lines(fitted3 ~ age, data=lex2, lwd=3, lty="solid"); 
	} else {
		lines(fitted ~ age, data=lex2, lwd=3, lty="solid"); 
	}
}
if (chartmode=="pdf") {dev.off()}










#######################
##   KVT/TVK by direction
######################
quartz.fnc(cwidth=9,cheight=8,cname="n.KVTTVK.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,2,1),mfrow=c(2,1))
x = xtabs(~ prod_new[drop=T]  + I(days_old), data=subset(lex,places=="KVT" &!deletion))
lex2=data.frame(age=as.numeric(colnames(x)), faith=as.numeric(x[1,]), K=as.numeric(x[2,]), T=as.numeric(x[3,]), row.names=NULL)
lex2$total = lex2$faith + lex2$K + lex2$T
lex2$unfaith = lex2$K + lex2$T
plot(unfaith/faith ~ age, data=lex2,  type="n", xlab="", ylab="tokens", cex.lab=1.6, ylim=c(0,1), xlim=c(360,1130), yaxt="n", xaxt="n", cex.main=2, main="KVT", cex.main=2);trevor.axes();
lines(lex2$faith/lex2$total ~ lex2$age,type="p", cex=log(lex2$faith+lex2$unfaith), col="gray50", lwd=.3);
	lex2$age2 = lex2$age - 802
	lex2$indicator = lex2$age > 802
lex2.glm8 = glm(cbind(faith, unfaith) ~ age2:indicator, family = "binomial", data = lex2);summary(lex2.glm8);lex2$fittedL = fitted(lex2.glm8); lines(fittedL ~ age, data=lex2, lwd=3, lty="solid") 
lines(lex2$K/lex2$total ~ lex2$age,type="p", pch="K", cex=log(lex2$K)+.6, col="blue")
lines(lex2$T/lex2$total ~ lex2$age,type="p", pch="T", cex=log(lex2$T)+.6, col="#CC0000")
#
x = xtabs(~ prod_new[drop=T]  + I(days_old), data=subset(lex,places=="TVK" &!deletion))
lex2=data.frame(age=as.numeric(colnames(x)), faith=as.numeric(x[1,]), K=as.numeric(x[2,]), T=as.numeric(x[3,]), row.names=NULL)
lex2$total = lex2$faith + lex2$K + lex2$T
lex2$unfaith = lex2$K + lex2$T
plot(unfaith/faith ~ age, data=lex2,  type="n", xlab="", ylab="tokens", cex.lab=1.6, ylim=c(0,1), xlim=c(360,1130), yaxt="n", xaxt="n", cex.main=2, main="TVK", cex.main=2);trevor.axes();
lines(lex2$faith/lex2$total ~ lex2$age,type="p", cex=log(lex2$faith+lex2$unfaith), col="gray50", lwd=.3);
lex2.glm8 = glm(cbind(faith, unfaith) ~ age, family = "binomial", data = lex2);summary(lex2.glm8);lex2$fittedL = fitted(lex2.glm8); lines(fittedL ~ age, data=lex2, lwd=3, lty="solid") 
lines(lex2$K/lex2$total ~ lex2$age,type="p", pch="K", cex=log(lex2$K)+.6, col="blue")
lines(lex2$T/lex2$total ~ lex2$age,type="p", pch="T", cex=log(lex2$T)+.6, col="#CC0000")
if (chartmode=="pdf") {dev.off()}






# KVT tokens vs. TVK tokens: basic vs. change point
quartz.fnc(cwidth=8,cheight=8,cname="n.TVK.vs.KVT.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,5,1),mfrow=c(3,2))
for(place in c("TVK","KVT")) {
	x = xtabs(~ prod_new[drop=T] + I(days_old), data=subset(lex, places==place &!deletion))
	lex2=data.frame(age=as.numeric(colnames(x)), faith=as.numeric(x[1,]), K=as.numeric(x[2,]), 	T=as.numeric(x[3,]), row.names=NULL)
	lex2$total = lex2$faith + lex2$K + lex2$T
	lex2$unfaith = lex2$K + lex2$T
	plot(unfaith/faith ~ age, data=lex2,  type="n", xlab="", ylab="faithful tokens", cex.lab=1.6, ylim=c(0,1), xlim=c(360,1130), main= place, yaxt="n", xaxt="n", cex.main=2);trevor.axes();
	lines(faith/total ~ age, data=subset(lex2,age<1730), type="p", lwd=.3, cex=log(lex2$faith+lex2$unfaith+.2), col="gray50");
	lex2$age2 = lex2$age - ifelse(place=="TVK", 766, 802)
	lex2$indicator = lex2$age > ifelse(place=="TVK", 766, 802)
	lex2.glm8 = glm(cbind(faith, unfaith) ~ age2:indicator, family = "binomial", data = lex2);summary(lex2.glm8);lex2$fittedL = fitted(lex2.glm8); lines(fittedL ~ age, data=lex2, lwd=3, lty="solid")
	lex2.glm = glm(cbind(faith, unfaith) ~ age2 , family = "binomial", data = lex2);summary(lex2.glm);lex2$fittedR = fitted(lex2.glm); lines(fittedR ~ age, data=lex2, lwd=2, lty="dashed")
	print(anova(lex2.glm, lex2.glm8, test="Chisq"))
}
if (chartmode=="pdf") {dev.off()}








# KVT tokens: linear vs. change point
quartz.fnc(cwidth=9,cheight=4,cname="n.KVT.Kside.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,1,1),mfrow=c(1,1))
x = xtabs(~ prod_new[drop=T]  + I(days_old), data=subset(lex,places=="KVT" &!deletion))
lex2=data.frame(age=as.numeric(colnames(x)), faith=as.numeric(x[1,]), K=as.numeric(x[2,]), T=as.numeric(x[3,]), row.names=NULL)
lex2$total = lex2$faith + lex2$K + lex2$T
lex2$unfaith = lex2$K + lex2$T
plot(unfaith/faith ~ age, data=lex2,  type="n", xlab="", ylab="faithful tokens", cex.lab=1.6, ylim=c(0,1), xlim=c(360,1130), main="", yaxt="n", xaxt="n", cex.main=2);trevor.axes();
lines(faith/(faith+K) ~ age, data=subset(lex2,age<1730), type="p", lwd=.3, cex=log(lex2$faith+lex2$unfaith+.2), col="gray50");
lex2$age2 = lex2$age -597
lex2$indicator = lex2$age > 597
lex2.glm8 = glm(cbind(faith, K) ~ age2:indicator, family = "binomial", data = lex2);summary(lex2.glm8);lex2$fittedL = fitted(lex2.glm8); lines(fittedL ~ age, data=lex2, lwd=4, lty="solid")
lex2.glm = glm(cbind(faith, K) ~ age2, family = "binomial", data = lex2);summary(lex2.glm);lex2$fittedL = fitted(lex2.glm); lines(fittedL ~ age, data=lex2, lwd=3, lty="dashed")
anova(lex2.glm, lex2.glm8, test="Chisq")
if (chartmode=="pdf") {dev.off()}













# change point K dominant
library(languageR)
quartz.fnc(cwidth=9,cheight=4,cname="n.KVT.lmer.Kdom.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,1,1),mfrow=c(1,1))
kvt = subset(lex,places=="KVT"&!deletion&prod_new!="T-dominant")
kvt = kvt[order(kvt$days_old),]
kvt$indicator = kvt$days_old>580
kvt$days_old2 = kvt$days_old-580
lmer1 = lmer(prod_new =="faithful" ~ days_old2 + (1 |type), data=kvt, family="binomial")
lmer2 = lmer(prod_new =="faithful" ~ days_old2:indicator + (1|type), data=kvt, family="binomial");anova(lmer1,lmer2)
a1 = fixef(lmer2)[1] + ifelse(!kvt$indicator, fixef(lmer2)[2]*kvt$days_old2, fixef(lmer2)[3]* kvt$days_old2) + mean(ranef(lmer2)$type[,1]);
plot(fitted(lmer2) ~ kvt$days_old, type="n",  cex=.7, lwd=.3, col="black", ylim=c(0,1), yaxt="n", xaxt="n",  xlab="", ylab="faithful tokens", cex.lab=1.6);trevor.axes();
lines(plogis(a1) ~ kvt$days_old, type="l", lwd=4, ylim=c(0,1))
text(fitted(lmer2) ~ kvt$days_old, label=kvt$type,  cex=.5);
if (chartmode=="pdf") {dev.off()}



# change point T dominant
library(languageR)
quartz.fnc(cwidth=9,cheight=4,cname="n.KVT.lmer.Tdom.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,1,1),mfrow=c(1,1))
kvt = subset(lex,places=="KVT"&!deletion&prod_new!="K-dominant")
kvt = kvt[order(kvt$days_old),]
kvt$indicator = kvt$days_old>800
kvt$days_old2 = kvt$days_old-800
lmer1 = lmer(prod_new =="faithful" ~ days_old2 + (1 |type), data=kvt, family="binomial")
lmer2 = lmer(prod_new =="faithful" ~ days_old2:indicator + (1|type), data=kvt, family="binomial");anova(lmer1,lmer2)
a1 = fixef(lmer2)[1] + ifelse(!kvt$indicator, fixef(lmer2)[2]*kvt$days_old2, fixef(lmer2)[3]* kvt$days_old2) + mean(ranef(lmer2)$type[,1]);
plot(fitted(lmer2) ~ kvt$days_old, type="n",  cex=.7, lwd=.3, col="black", ylim=c(0,1), yaxt="n", xaxt="n",  xlab="", ylab="faithful tokens", cex.lab=1.6);trevor.axes();
lines(plogis(a1) ~ kvt$days_old, type="l", lwd=4, ylim=c(0,1))
text(fitted(lmer2) ~ kvt$days_old, label=kvt$type,  cex=.5);
if (chartmode=="pdf") {dev.off()}
summary(kvt)












##############################################
#########                       ##############
######### S I M U L A T I O N S ##############
#########                       ##############
##############################################

## complex onsets
sim3 = read.csv("sim.onsets.csv",header=F)
colnames(sim3) = c("sim","age","grammar","lexicon","type","production")
sim3$window = floor(1:2009/25)
quartz.fnc(cwidth=9,cheight=4,cname="n.sim.onsets.pdf")
par(family=myfont,ps=pointsize,mar=c(4,5,1,1),mfrow=c(1,1))
plot(0~0, type="n", ylim=c(0,1), xlim=c(0,80), ylab="tokens", yaxt="n", xlab="simulated time", cex.lab=1.6, cex.axis=1.5, xaxt="n");trevor.axes();axis(1, at=seq(0,80,8), paste(seq(0,10)*10,"%", sep=""))
for(s in 0:99) {
	lines(with(subset(sim3, sim==s),aggregate(production=="faithful", list(window), mean)), type="l", lwd=.2, col="gray80")
}	
mean = with(sim3,aggregate(production=="faithful", list(window), mean));lines(mean, lwd=3)
if (chartmode=="pdf") {dev.off()}





sim2 = read.csv("sim.harmony.TVK.csv",header=F)
colnames(sim2) = c("sim","age","grammar","lexicon","type","place","production")
sim2K = subset(sim2,place==1);summary(sim2K)
sim2T = subset(sim2,place==0);summary(sim2T)
sim2K$window = floor(1:998/10)
sim2T$window = floor(1:596/10)
#
quartz.fnc(cwidth=9,cheight=9,cname="n.sim.harmony.pdf")
par(family=myfont,ps=pointsize,mar=c(5,5,3,1),mfrow=c(2,1))
plot(0~0, type="n", xlim=c(0,75),ylim=c(0,1), ylab="tokens", yaxt="n", xlab="simulated time", cex.lab=1.6, cex.axis=1.5, xaxt="n",main="KVT", cex.main=2);trevor.axes();axis(1, at=seq(0,75,7.5), paste(seq(0,10)*10,"%", sep=""))
for(s in 0:99) {
	lines(with(subset(sim2K, sim==s),aggregate(production=="faithful", list(window), mean)[1:76,]), type="l", lwd=.2, col="gray80")
}	
mean = with(sim2K,aggregate(production=="faithful", list(window), mean));lines(mean[1:76,], lwd=3)
T=with(sim2K,aggregate(production=="k⟶t", list(window), mean))
lines(T, type="p", pch="T", col="#CC0000", cex=T$x*2.5)
K=with(sim2K,aggregate(production=="t⟶k", list(window), mean))
lines(K, type="p", pch="K", col="blue", cex=K$x*2.5)
#
plot(0~0, type="n", xlim=c(0,45),ylim=c(0,1), ylab="tokens", yaxt="n", xlab="simulated time", cex.lab=1.6, cex.axis=1.5, xaxt="n",main="TVK", cex.main=2);trevor.axes();trevor.axes();axis(1, at=seq(0,45,4.5), paste(seq(0,10)*10,"%", sep=""))
for(s in 0:99) {
	lines(with(subset(sim2T, sim==s),aggregate(production=="faithful", list(window), mean))[1:46,], type="l", lwd=.2, col="gray80")
}	
mean = with(sim2T,aggregate(production=="faithful", list(window), mean));lines(mean[1:46,], lwd=3)
T=with(sim2T,aggregate(production=="k⟶t", list(window), mean))
lines(T, type="p", pch="T", col="#CC0000", cex=T$x*2.5)
K=with(sim2T,aggregate(production=="t⟶k", list(window), mean))
lines(K, type="p", pch="K", col="blue", cex=K$x*2.5)
if (chartmode=="pdf") {dev.off()}





























